@@ -230,9 +230,6 @@ class UpdatesAvailable(InternalDialog):
         self.dl_size = 0
         self.connected = True
 
-        # Used for inhibiting power management
-        self.sleep_cookie = None
-
         self.settings = Gio.Settings.new("com.ubuntu.update-manager")
 
         # Special icon theme for looking up app-install-data icons
@@ -676,7 +673,7 @@ class UpdatesAvailable(InternalDialog):
                                 callback_args)
 
             def hide_button(args):
-                nonlocal id, button
+                nonlocal id
                 if id is not None:
                     button.disconnect(id)
                     id = None
